@@ -34,6 +34,14 @@ class Mitigation(BaseModel):
     x_mitre_modified_by_ref: Id = field(factory=Id)
     x_mitre_domains: List[MitreDomain] = field(factory=list)
 
+    revoked: bool = field(factory=bool)
+
+    def __init__(self, **kwargs):
+        try:
+            self.__attrs_init__(**kwargs)
+        except TypeError as te:
+            raise te
+
     def __attrs_post_init__(self):
         if self.external_references:
             return_list = []
